@@ -7,7 +7,7 @@
 from cookiecutter.main import cookiecutter
 from python_on_whales import docker
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 COOKIECUTTER_URL = "https://github.com/anvilistas/amoni-cookiecutter.git"
 
@@ -34,18 +34,31 @@ def pull_image(name: str) -> None:
 
     Parameters
     ----------
-    name : The name of the image to pull
+    name
+        The name of the image to pull
     """
     docker.compose.pull([name])
 
 
+def build_image(name: str) -> None:
+    """Build a docker image
+    Parameters
+    ----------
+    name
+        The name of the image to pull
+    """
+    docker.compose.build([name], pull=True)
+
+
 def start_service(name: str, detach: bool) -> None:
     """Start a given service
 
     Parameters
     ----------
-    name : The name of the service to start
-    detach : Whether to detach from the service console
+    name
+        The name of the service to start
+    detach
+        Whether to detach from the service console
     """
     docker.compose.up([name], detach=detach)
 
@@ -60,6 +73,7 @@ def run_service(name: str) -> None:
 
     Parameters
     ----------
-    name : The name of the service to start
+    name
+        The name of the service to start
     """
     docker.compose.run(name)
